library witsystem_device_manage;

import 'package:witsystem_device_manage/generated/l10n.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:witsystem_device_plugin/device/DeviceManage.dart';
import 'package:witsystem_device_plugin/device/Unlock.dart';
import 'package:witsystem_device_manage/assets/icons/WitsIcon.dart';
import 'package:witsystem_device_manage/colors/ThemeColors.dart';

class WitsystemDeviceListWidget extends StatefulWidget {
  const WitsystemDeviceListWidget({Key? key}) : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return DeviceListState();
  }
}

class DeviceListState extends State<WitsystemDeviceListWidget> {
  List deviceList = [];

  @override
  void initState() {
    super.initState();
    init();
  }

  init() async {
    var list = await DeviceManage.instance.deviceList();
    setState(() {
      deviceList.addAll(list);
    });
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      color: ThemeColors.theme,
      padding: const EdgeInsets.fromLTRB(10, 10, 10, 10),
      child: GridView.builder(
          gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
              crossAxisCount: 2,
              crossAxisSpacing: 10,
              mainAxisSpacing: 10,
              childAspectRatio: 1.5),
          itemCount: deviceList.length,
          itemBuilder: (context, index) {
            return Container(
              decoration: BoxDecoration(
                color: ThemeColors.themeItem,
                borderRadius: const BorderRadius.all(Radius.circular(4.0)),
                //设置四周圆角 角度
                border:
                    Border.all(width: 1, color: ThemeColors.themeItem), //设置四周边框
              ),
              padding: const EdgeInsets.fromLTRB(5, 5, 5, 15),
              child: Column(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  // Image.asset("images/t3.png",package: "witsystem_theme_a"),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: [
                      Expanded(
                        flex: 1,
                        child: Text("${deviceList[index]['deviceName']}",
                            maxLines: 1,
                            overflow: TextOverflow.ellipsis,
                            style: const TextStyle(
                              color: Colors.white,
                              fontSize: 12,
                            )),
                      ),
                      Text(
                          deviceList[index]['device']['onLine'] ? S.of(context).onLine : S.of(context).offLine,
                          style: const TextStyle(color: Colors.white,fontSize: 12)),
                    ],
                  ),
                  deviceList[index]['device']['type'] == 'Slock'
                      ? Row(
                          mainAxisAlignment: MainAxisAlignment.spaceBetween,
                          children: [
                            Icon(
                              WitsIcon.mensuo,
                              color: (deviceList[index]['device']['onLine']
                                  ? Colors.green
                                  : Colors.red),
                              size: 40,
                            ),
                            GestureDetector(
                              child: const Padding(
                                padding: EdgeInsets.all(10),
                                child: Icon(
                                  WitsIcon.open,
                                  color: Colors.red,
                                  size: 20,
                                ),
                              ),
                              onTap: () {
                                Unlock.instance.bleUnlock(
                                    deviceList[index]['device']['deviceId']);
                              },
                            )
                          ],
                        )
                      : deviceList[index]['device']['type'] == 'Ammet'
                          ? Row(
                              mainAxisAlignment: MainAxisAlignment.spaceBetween,
                              children: [
                                Icon(
                                  WitsIcon.dianbiao,
                                  color: (deviceList[index]['device']['onLine']
                                      ? Colors.green
                                      : Colors.red),
                                  size: 40,
                                ),
                                Text(
                                    "${deviceList[index]['device']['devicesAmmet']['balance']}",
                                    style: const TextStyle(color: Colors.white,fontSize: 12))
                              ],
                            )
                          : deviceList[index]['device']['type'] == 'Relay'
                              ? Row(
                                  mainAxisAlignment:
                                      MainAxisAlignment.spaceBetween,
                                  children: [
                                    Icon(
                                      WitsIcon.luyouqi,
                                      color: (deviceList[index]['device']
                                              ['onLine']
                                          ? Colors.green
                                          : Colors.red),
                                      size: 40,
                                    ),
                                    const Icon(WitsIcon.xinhao)
                                  ],
                                )
                              : deviceList[index]['device']['type'] == 'Water'
                                  ? Row(
                                      mainAxisAlignment:
                                          MainAxisAlignment.spaceBetween,
                                      children: [
                                        Icon(
                                          WitsIcon.shuibiao,
                                          color: (deviceList[index]['device']
                                                  ['onLine']
                                              ? Colors.green
                                              : Colors.red),
                                          size: 40,
                                        ),
                                        Text(
                                            "${deviceList[index]['device']['devicesWater']['balance']}",
                                            style: const TextStyle(
                                                color: Colors.white))
                                      ],
                                    )
                                  : Row(
                                      mainAxisAlignment:
                                          MainAxisAlignment.spaceBetween,
                                      children: [
                                        Icon(
                                          WitsIcon.shebei,
                                          color: (deviceList[index]['device']
                                                  ['onLine']
                                              ? Colors.green
                                              : Colors.red),
                                          size: 40,
                                        ),
                                        const Text("...",
                                            style:
                                                TextStyle(color: Colors.white))
                                      ],
                                    ),
                ],
              ),
            );
          }),
    );
  }
}
